@@ -1,7 +1,8 @@
 use crate::black_list::contains;
 use crate::configuration::Configuration;
 use crate::page::Page;
-use crate::utils::{log, Client};
+use crate::utils::{log};
+use reqwest::blocking::{Client};
 use rayon::ThreadPool;
 use rayon::ThreadPoolBuilder;
 use robotparser_fork::RobotFileParser;
@@ -18,7 +19,6 @@ use tokio::time::sleep;
 /// let mut localhost = Website::new("http://example.com");
 /// localhost.crawl();
 /// // `Website` will be filled with `Pages` when crawled. To get them, just use
-/// 
 /// for page in localhost.get_pages() {
 ///     // do something
 /// }
